@@ -14,7 +14,7 @@
 	else {
 	  years = 1;
 	}
-	created = $('input:hidden[name=created]').val();
+	created = $('input:hidden[name=now]').val();
 	var parts = created.split('-');
 	// new Date(year, month [, day [, hours[, minutes[, seconds[, ms]]]]])
 	var retention_date = new Date(parts[2], parts[1], parts[0]); // Note: months are 0-based
